@@ -1,5 +1,5 @@
 package XML::TMX::CWB;
-$XML::TMX::CWB::VERSION = '0.09';
+$XML::TMX::CWB::VERSION = '0.10';
 use warnings;
 use strict;
 use Lingua::PT::PLNbase;
@@ -207,8 +207,9 @@ sub _encode {
         my $f = $files[$i];
 
         if ($tagged && exists($tagged->{languages}{$l})) {
-           shift @{$tagged->{'pos-fields'}};
-           $posatt = join(" ", map { "-P $_" } @{$tagged->{'pos-fields'}});
+#           shift @{$tagged->{'pos-fields'}};
+           my (undef, @tags) = @{$tagged->{'pos-fields'}};
+           $posatt = join(" ", map { "-P $_" } @tags);
            $sattr  = join(" ", map { "-S $_" } @{$tagged->{'pos-s-attributes'}});
         }        
     
